#
# spec file for package jackson-dataformat-xml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jackson-dataformat-xml
Version:        2.17.3
Release:        1.2
Summary:        Jackson extension component for reading and writing XML encoded data
License:        Apache-2.0
URL:            https://github.com/FasterXML/jackson-dataformat-xml
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-annotations)
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core)
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:)
BuildRequires:  mvn(com.fasterxml.woodstox:woodstox-core)
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.codehaus.woodstox:stax2-api)
BuildArch:      noarch

%description
Data format extension for Jackson (http://jackson.codehaus.org)
to offer alternative support for serializing POJOs as XML and
deserializing XML as POJOs. Support implemented on top of Stax API
(javax.xml.stream), by implementing core Jackson Streaming API types
like JsonGenerator, JsonParser and JsonFactory. Some data-binding types
overridden as well (ObjectMapper sub-classed as XmlMapper).

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin :moditect-maven-plugin
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :gradle-module-metadata-maven-plugin

%{mvn_file} ":{*}" jackson-dataformats/@1

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md release-notes/*
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Wed Nov  6 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 2.17.3
  * No changes since 2.17.2
* Wed Aug  7 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 2.17.2
  * #657: Nesting depth in `XmlReadContext` is not
    incremented/decremented on
    JsonToken.START_OBJECT/JsonToken.END_OBJECT
  * Upgrade Woodstox to 6.7.0 (dependency fixes)
* Mon May 20 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to 2.17.1
  * #646: Deserializing fails when using builder classes with
    `Iterable` Collection setters (fix contributed by Bas P)
  * Upgrade Woodstox to 6.6.2 (dependency fixes)
- Includes changes from 2.17.0
  * #324: Support use of `xsi:type` for polymorphic serialization
    (`ToXmlGenerator.Feature.AUTO_DETECT_XSI_TYPE`)
  * #618: `ArrayIndexOutOfBoundsException` thrown for invalid
    ending XML string when using JDK default Stax XML parser
  * #631: Add `XmlMapper.createGenerator(XMLStreamWriter)` and
    `XmlMapper.createParser(XMLStreamReader)` overloads
  * #634: Support use of xsi:type for polymorphic deserialization
    (FromXmlParser.Feature.AUTO_DETECT_XSI_TYPE)
  * #637: `JacksonXmlAnnotationIntrospector.findNamespace()` should
    properly merge namespace information
  * #643: XML serialization of floating-point infinity is
    incompatible with JAXB and XML Schema (contributed by Alex H)
  * Upgrade Woodstox to 6.6.1 (latest at the time)
* Fri Mar  8 2024 Gus Kenion <gkenion@suse.com>
- Upgrade to 2.16.1
  * 2.16.1 (24-Dec-2023)
    + #616: Fix mismatch in setNextIsUnwrapped(boolean) in
    XmlBeanSerializerBase#serializeFieldsFiltered()
  * 2.16.0 (15-Nov-2023)
    + #148: @JacksonXmlElementWrapper not respected when
    serializing Iterators / Iterables
    + #302: Unable to serialize top-level Java8 Stream
    + #329: @JacksonXmlElementWrapper ignored on Stream
    + #599: Use IterationType in TypeUtil
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Version update to 2.15.2
  * No changes since 2.15.0
  * 2.15.0 (23-Apr-2023)
    + #286: Conflict between '@JsonIdentityInfo' and Unwrapped Lists
    + #533: (Android) java.lang.NoClassDefFoundError: Failed
    resolution of: Ljavax/xml/stream/XMLInputFactory
    + #542: 'XmlMapper' does not find no-argument record constructor
    for deserialization of empty XML
    + #547: Parsing empty tags without default no-arguments
    constructor fails in 2.14
    + #560: Add 'DefaultXmlPrettyPrinter.withCustomNewLine()' to
    configure linefeed for XML pretty-printing
    + #578: 'XmlMapper' serializes '@JsonAppend' property twice
    + #584: Deserialization of 'null' String values in
    Arrays / 'Collection's not working as expected
  * 2.14.2 (28-Jan-2023)
    + Upgrade Woodstox to 6.5.0 for a fix to OSGi metadata
  * 2.14.0 (05-Nov-2022)
    + #491: 'XmlMapper' 2.12 regression: no default no-arg ctor
    found
    + #498: 'XmlMapper' fails to parse XML array when the array only
    has one level
    + #531: Add mechanism for processing invalid XML names
    (transforming to valid ones)
    + #538: Required attribute of '@JsonProperty' is ignored when
    deserializing from XML
    + #545: '@JacksonXmlText' does not work when paired with
    '@JsonRawValue'
    + #550: Use of 'ClassLoader'-taking 'newFactory()' variant
    breaks applications using default JDK XML implementation
    + Upgrade Woodstox to 6.4.0 for a fix to [CVE-2022-40152,
    bsc#1203521]
  * 2.13.5 (23-Jan-2023)
    + Upgrade Woodstox to 6.4.0 for a fix to [CVE-2022-40152,
    bsc#1203521]
  * 2.13.4 (03-Sep-2022)
    + #536: Upgrade Woodstox to 6.3.1 to get OSGi metadata
* Tue Jun 14 2022 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-dataformat-xml 2.13.3
